# plotter for the 1-D lattice harmonic oscillator data

# launch from command-line with: gnuplot plotter.gp

set term postscript color enhanced 18 eps

# parameters for the continuum T=infinity curve
eta = 1.0
mu  = 8.0
continuum(tau) = (1./(2.*eta*mu*mu))*exp(-tau*(eta*mu))

# 1: linear scale, plot
set auto
set xlabel 't/T'
set ylabel 'C(t)/T^2'
set key right top
set output '1_correlator.eps'
plot \
  'N_08.dat' u 1:2 w po lw 3 t 'N = 08', \
  'N_16.dat' u 1:2 w po lw 3 t 'N = 16', \
  'N_32.dat' u 1:2 w po lw 3 t 'N = 32', \
  continuum(x) lw 2 t 'T = {/Symbol \245}, continuum'

# 2: log scale, plot
set output '2_log_correlator.eps'
set xlabel 't/T'
set ylabel 'C(t)/T^2'
set yrange [0.0002:0.01]
set key right bottom
set logscale y
replot

# 3: plot of -log(C) for checking its slope
unset logscale y
set xlabel 't/T'
set ylabel '-log(C)'
set yrange [4:9]
set key right bottom
set output '3_minus_log_c.eps'
plot \
  'N_08.dat' u 1:(-log($2)) w po lw 3 t 'N = 08', \
  'N_16.dat' u 1:(-log($2)) w po lw 3 t 'N = 16', \
  'N_32.dat' u 1:(-log($2)) w po lw 3 t 'N = 32', \
  (-log(continuum(x))) lw 2 t 'T = {/Symbol \245}, continuum'

# 3b: linear fit in an "intermediate" window
f(x) = a+b*x
fit [0.03125:0.28125] f(x) 'N_32.dat' u 1:(-log($2)) via a,b
# gives slope of: 7.88(2) ~ should be 8 ( = omega T = eta mu ) : not bad ...
# to make it better: enlarge N further, restrict the fit range to a shorter region centered around 0.2/0.25, etc ...

# 4: account for the periodicity with the first "mirror-correlation", that is, 1 - tau.
mirrored(tau) = continuum(tau) + continuum(1-tau)
set xlabel 't/T'
set ylabel 'C(t)/T^2'
set auto
set key right top
set output '4_mirrored_correlator.eps'
plot \
  'N_08.dat' u 1:2 w po lw 3 t 'N = 08', \
  'N_16.dat' u 1:2 w po lw 3 t 'N = 16', \
  'N_32.dat' u 1:2 w po lw 3 t 'N = 32', \
  mirrored(x) lw 2 t 'T = {/Symbol \245}, continuum, mirrored'

# 5: log scale of the above (mirrored), plot
set output '5_log_mirrored_correlator.eps'
set xlabel 't/T'
set ylabel 'C(t)/T^2'
set yrange [0.0002:0.01]
set key right bottom
set logscale y
replot
